@@ -1,5 +1,5 @@
 package Log::Dispatch::Syslog;
-$Log::Dispatch::Syslog::VERSION = '2.42';
+$Log::Dispatch::Syslog::VERSION = '2.43';
 use strict;
 use warnings;
 
@@ -75,16 +75,17 @@ sub _init {
     ];
 }
 
-my $thread_lock;
+my $thread_lock : shared = 0;
+
 sub log_message {
     my $self = shift;
     my %p    = @_;
 
     my $pri = $self->_level_as_number( $p{level} );
 
-    eval {
-        threads::shared::lock($thread_lock) if $self->{lock};
+    lock($thread_lock) if $self->{lock};
 
+    eval {
         if ( defined $self->{socket} ) {
             Sys::Syslog::setlogsock(
                 ref $self->{socket} && reftype( $self->{socket} ) eq 'ARRAY'
@@ -121,7 +122,7 @@ Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 VERSION
 
-version 2.42
+version 2.43
 
 =head1 SYNOPSIS
 
